@@ -148,7 +148,7 @@ class Elbow:
 			try:
 				score_list = self.get_optimal_number_of_clusters(by=by)
 				list_of_score_lists.append(score_list)
-			except:
+			except TypeError:
 				continue
 
 		return max(*list_of_score_lists)
